# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..regutils import RegJacobian


def test_RegJacobian_inputs():
    input_map = dict(
        args=dict(argstr="%s",),
        environ=dict(nohash=True, usedefault=True,),
        omp_core_val=dict(argstr="-omp %i", usedefault=True,),
        out_file=dict(
            argstr="%s",
            extensions=None,
            name_source=["trans_file"],
            name_template="%s",
            position=-1,
        ),
        ref_file=dict(argstr="-ref %s", extensions=None,),
        trans_file=dict(argstr="-trans %s", extensions=None, mandatory=True,),
        type=dict(argstr="-%s", position=-2, usedefault=True,),
    )
    inputs = RegJacobian.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_RegJacobian_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = RegJacobian.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value
