# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import TProject


def test_TProject_inputs():
    input_map = dict(
        TR=dict(argstr="-TR %g",),
        args=dict(argstr="%s",),
        automask=dict(argstr="-automask", xor=["mask"],),
        bandpass=dict(argstr="-bandpass %g %g",),
        blur=dict(argstr="-blur %g",),
        cenmode=dict(argstr="-cenmode %s",),
        censor=dict(argstr="-censor %s", extensions=None,),
        censortr=dict(argstr="-CENSORTR %s",),
        concat=dict(argstr="-concat %s", extensions=None,),
        dsort=dict(argstr="-dsort %s...",),
        environ=dict(nohash=True, usedefault=True,),
        in_file=dict(
            argstr="-input %s",
            copyfile=False,
            extensions=None,
            mandatory=True,
            position=1,
        ),
        mask=dict(argstr="-mask %s", extensions=None,),
        noblock=dict(argstr="-noblock",),
        norm=dict(argstr="-norm",),
        num_threads=dict(nohash=True, usedefault=True,),
        ort=dict(argstr="-ort %s", extensions=None,),
        out_file=dict(
            argstr="-prefix %s",
            extensions=None,
            name_source="in_file",
            name_template="%s_tproject",
            position=-1,
        ),
        outputtype=dict(),
        polort=dict(argstr="-polort %d",),
        stopband=dict(argstr="-stopband %g %g",),
    )
    inputs = TProject.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_TProject_outputs():
    output_map = dict(out_file=dict(extensions=None,),)
    outputs = TProject.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value
